;; Generated package description from embark-consult.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "embark-consult" "1.2.0.20260606.19" "Consult integration for Embark" '((emacs "29.1") (compat "31") (embark "1.1") (consult "3.2")) :commit "d3da7e40d4dab4b302766498833ffeaccb89cdd5" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
